/*    This is a sample of Blink LED program
 *  for STM32F100C4T6 ARM Cortex-M3 uController
 *    Code designed for STM32F1DIP40 module
 *    but you can build it for other MCU's
 */
//************************************************************
#include "stm32f10x.h"
//************************************************************
void InitPeripheral (void);
void DelayInit(unsigned int);
void _delay_ms(unsigned int);
void SysTick_Decrement(void);
//************************************************************
GPIO_InitTypeDef    GPIO_InitStruct;
volatile static unsigned int SysTickDelay;//
//************************************************************
// Define LED pins
//************************************************************
#define LED_ON GPIO_WriteBit(GPIOB, GPIO_Pin_11, 0)
#define LED_OFF GPIO_WriteBit(GPIOB, GPIO_Pin_11, 1)

//************************************************************
// In this function we setup peripheral
// and SysTick timer for work
//************************************************************
void InitPeripheral (void)
{
	// Init Delay_ms (System frequency in kHz)
	DelayInit(72000);

	// Initialization of LED Pins
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE);// Clock PORTB Enable
	GPIO_InitStruct.GPIO_Pin = GPIO_Pin_11; // Configure Led pin
	GPIO_InitStruct.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_InitStruct.GPIO_Mode = GPIO_Mode_Out_PP;// Set Output Push-Pull
	GPIO_Init(GPIOB, &GPIO_InitStruct);
}

//************************************************************
// Initialization of SysTick timer for
// generate interrupt every 1ms
//************************************************************
void DelayInit(unsigned int system_freq_khz)
{
	SysTick_Config(system_freq_khz);
}

//************************************************************
// Delay in milliseconds
//************************************************************
void _delay_ms(unsigned int ms)
{
  SysTickDelay = ms;
  while(SysTickDelay != 0);
}

//************************************************************
// This function called in stm32f10x_it.c
// Interrupt of SysTick called every 1ms
//************************************************************
void SysTick_Decrement(void)
{
	if (SysTickDelay != 0x00)
	{
		SysTickDelay--;
	}
}

//************************************************************
// MAIN function
//************************************************************
int main(void)
{
// START main program

	InitPeripheral ();// Initialization LED and SysTick timer

// Main loop cycle
    while(1)
    {
    	LED_ON;	// Set LED pin to HI logic level
    	_delay_ms(250);// Delay = 250 milliseconds
    	LED_OFF;// Set LED pin to LOW logic level
    	_delay_ms(250);// Delay = 250 milliseconds
    }

return 0;
}
//************************************************************
// END of file
//************************************************************

